@@ -31,7 +31,7 @@ def _load_frame(filename):
         df.loc[:, ["A", "B", "C", "D", "E"]]
     )  # some of these are not closed to 100%
     df = df.set_index("Specimen")
-    df.name = titlecase(path.stem)
+    df.attrs["name"] = titlecase(path.stem)
     return df
 
 
