@@ -5,10 +5,9 @@ from ...comp.codata import close, inverse_ILR, ILR, ALR, inverse_ALR
 from ...util.math import flattengrid
 from ...util.distributions import sample_kde
 from ...util.plot.grid import bin_centres_to_edges
-import logging
+from ...util.log import Handle
 
-logging.getLogger(__name__).addHandler(logging.NullHandler())
-logger = logging.getLogger(__name__)
+logger = Handle(__name__)
 
 
 def ternary_heatmap(
