@@ -3,14 +3,20 @@ import matplotlib.lines
 import matplotlib.patches
 import matplotlib.collections
 import numpy as np
-import logging
+from ..util.log import Handle
 
-logging.getLogger(__name__).addHandler(logging.NullHandler())
-logger = logging.getLogger(__name__)
+logger = Handle(__name__)
 
+
+from .color import process_color
 from ..geochem.ind import get_ionic_radii, REE
 from ..util.types import iscollection
-from ..util.plot.style import DEFAULT_CONT_COLORMAP, _mpl_sp_kw_split, patchkwargs
+from ..util.plot.style import (
+    DEFAULT_CONT_COLORMAP,
+    linekwargs,
+    scatterkwargs,
+    patchkwargs,
+)
 from ..util.plot.density import (
     conditional_prob_density,
     plot_Z_percentiles,
@@ -20,22 +26,22 @@ from ..util.plot.axes import get_twins, init_axes
 
 from ..util.meta import get_additional_params, subkwargs
 
+_scatter_defaults = dict(cmap=DEFAULT_CONT_COLORMAP, marker="D", s=25,)
+_line_defaults = dict(cmap=DEFAULT_CONT_COLORMAP)
 
+# could create a spidercollection?
 def spider(
     arr,
     indexes=None,
     ax=None,
-    color=None,
-    cmap=DEFAULT_CONT_COLORMAP,
-    norm=None,
-    alpha=None,
-    marker="D",
-    markersize=5.0,
     label=None,
     logy=True,
     yextent=None,
     mode="plot",
     unity_line=False,
+    scatter_kw={},
+    line_kw={},
+    set_ticks=True,
     **kwargs
 ):
     """
@@ -51,16 +57,6 @@ def spider(
         Numerical indexes of x-axis positions.
     ax : :class:`matplotlib.axes.Axes`, :code:`None`
         The subplot to draw on.
-    color : :class:`str` | :class:`list` | :class:`numpy.ndarray`
-        Individual color or collection of :mod:`~matplotlib.colors` to be passed to matplotlib.
-    cmap : :class:`matplotlib.colors.Colormap`
-        Colormap for mapping point and line colors.
-    norm : :class:`matplotlib.colors.Normalize`, :code:`None`
-        Normalization instane for the colormap.
-    marker : :class:`str`, 'D'
-        Matplotlib :mod:`~matplotlib.markers` designation.
-    markersize : :class:`int`, 5.
-        Size of individual markers.
     label : :class:`str`, :code:`None`
         Label for the individual series.
     logy : :class:`bool`
@@ -72,7 +68,12 @@ def spider(
         a filled range. Density will return a conditional density diagram.
     unity_line : :class:`bool`
         Add a line at y=1 for reference.
-
+    scatter_kw : :class:`dict`
+        Keyword parameters to be passed to the scatter plotting function.
+    line_kw : :class:`dict`
+        Keyword parameters to be passed to the line plotting function.
+    set_ticks : :class:`bool`
+        Whether to set the x-axis ticks according to the specified index.
     {otherparams}
 
     Returns
@@ -108,6 +109,9 @@ def spider(
     if logy:
         ax.set_yscale("log")
 
+    if unity_line:
+        ax.axhline(1.0, ls="--", c="k", lw=0.5)
+
     if indexes is None:
         indexes = np.arange(ncomponents)
     else:
@@ -118,52 +122,98 @@ def spider(
     else:
         indexes0 = indexes[0]
 
-    ax.set_xticks(indexes0)
+    if set_ticks:
+        ax.set_xticks(indexes0)
 
     # if there is no data, return the blank axis
     if (arr is None) or (not np.isfinite(arr).sum()):
         return ax
 
+    # if the indexes are supplied as a 1D array but the data is 2D, we need to expand
+    # it to fit the scatter data
     if indexes.ndim < arr.ndim:
         indexes = np.tile(indexes0, (arr.shape[0], 1))
 
-    local_kw = dict(  # register aliases
-        c=color, color=color, marker=marker, markersize=markersize, s=markersize ** 2
-    )
-    local_kw = {**local_kw, **kwargs}
-    if local_kw.get("color") is None and local_kw.get("c") is None:
-        local_kw["color"] = next(ax._get_lines.prop_cycler)["color"]
-
-    sctkw, lnkw = _mpl_sp_kw_split(local_kw)
-    _ = lnkw.pop("label")
-    # check if colors vary per line/sctr
-    variable_colors = False
-    c = sctkw.get("c", None)
-
-    if c is not None:
-        if iscollection(c):
-            variable_colors = True
-
-    if unity_line:
-        ax.axhline(1.0, ls="--", c="k", lw=0.5)
-
     if "fill" in mode.lower():
         mins = np.nanmin(arr, axis=0)
         maxs = np.nanmax(arr, axis=0)
-        plycol = ax.fill_between(indexes0, mins, maxs, **patchkwargs(local_kw))
+        plycol = ax.fill_between(indexes0, mins, maxs, **patchkwargs(kwargs))
     elif "plot" in mode.lower():
-        ls = ax.plot(indexes.T, arr.T, **lnkw)
-        if variable_colors:
-            # perhaps check shape of color arg here
-            for l, ic in zip(ls, c):
-                l.set_color(ic)
+        # copy params
+        l_kw, s_kw = {**line_kw}, {**scatter_kw}
+        ################################################################################
+        if line_kw.get("cmap") is None:
+            l_kw["cmap"] = kwargs.get("cmap", None)
+
+        l_kw = {**kwargs, **l_kw}
+
+        # if a line color hasn't been specified, perhaps we can use the scatter 'c'
+        if l_kw.get("color") is None:
+            if l_kw.get("c") is not None:
+                l_kw["color"] = kwargs.get("c")
+        if "c" in l_kw:
+            l_kw.pop("c")  # remove c if it's been specified globally
+        # if a color option is not specified, get the next cycled color
+        if l_kw.get("color") is None:
+            # add cycler color as array to suppress singular color warning
+            l_kw["color"] = np.array([next(ax._get_lines.prop_cycler)["color"]])
+
+        l_kw = linekwargs(process_color(**{**_line_defaults, **l_kw}))
+        # marker explictly dealt with by scatter
+        for k in ["marker", "markers"]:
+            l_kw.pop(k, None)
+        # Construct and Add LineCollection?
+        lcoll = matplotlib.collections.LineCollection(
+            np.dstack((indexes, arr)), **{"zorder": 1, **l_kw}
+        )
+        ax.add_collection(lcoll)
+
+        ################################################################################
+        # load defaults and any specified parameters in scatter_kw / line_kw
+        if s_kw.get("cmap") is None:
+            s_kw["cmap"] = kwargs.get("cmap", None)
+
+        _sctr_cfg = {**_scatter_defaults, **kwargs, **s_kw}
+        s_kw = process_color(**_sctr_cfg)
+
+        if s_kw["marker"] is not None:
+            # will need to process colours for scatter markers here
+
+            s_kw.update(dict(label=label))
+
+            scattercolor = None
+            if s_kw.get("c") is not None:
+                scattercolor = s_kw.get("c")
+            elif s_kw.get("color") is not None:
+                scattercolor = s_kw.get("color")
+            else:
+                # no color recognised - will be default, here we get the
+                # cycled color we added earlier
+                scattercolor = l_kw["color"]
+
+            if scattercolor is not None:
+                if not isinstance(scattercolor, (str, tuple)):
+                    # colors will be processed to arrays by this point
+                    # here we reshape them to be the same length as ravel-ed arrays
+                    if scattercolor.ndim >= 2 and scattercolor.shape[0] > 1:
+                        scattercolor = np.tile(scattercolor, arr.shape[1]).reshape(
+                            -1, scattercolor.shape[1]
+                        )
+                else:
+                    # singular color should be converted to 2d array?
+                    pass
+            s_kw = scatterkwargs(
+                {k: v for k, v in s_kw.items() if k not in ["c", "color"]}
+            )
+            sc = ax.scatter(
+                indexes.ravel(), arr.ravel(), c=scattercolor, **{"zorder": 2, **s_kw}
+            )
 
-        sctkw.update(dict(label=label))
-        sc = ax.scatter(indexes.T, arr.T, **sctkw)
         # should create a custom legend handle here
 
         # could modify legend here.
     elif any([i in mode.lower() for i in ["binkde", "ckde", "kde", "hist"]]):
+        cmap = kwargs.pop("cmap", None)
         if "contours" in kwargs and "vmin" in kwargs:
             msg = "Combining `contours` and `vmin` arugments for density plots should be avoided."
             logger.warn(msg)
@@ -174,7 +224,7 @@ def spider(
             yextent=yextent,
             mode=mode,
             ret_centres=True,
-            **local_kw
+            **kwargs
         )
         # can have issues with nans here?
         vmin = kwargs.pop("vmin", 0)
@@ -190,7 +240,7 @@ def spider(
         else:
             zi[zi < vmin] = np.nan
             ax.pcolormesh(
-                xe, ye, zi, cmap=cmap, vmin=vmin, *subkwargs(kwargs, ax.pcolormesh)
+                xe, ye, zi, cmap=cmap, vmin=vmin, **subkwargs(kwargs, ax.pcolormesh)
             )
     else:
         raise NotImplementedError(
@@ -210,6 +260,10 @@ def REE_v_radii(
     logy=True,
     tl_rotation=60,
     unity_line=False,
+    scatter_kw={},
+    line_kw={},
+    set_labels=True,
+    set_ticks=True,
     **kwargs
 ):
     r"""
@@ -234,7 +288,14 @@ def REE_v_radii(
         Rotation of the numerical index labels in degrees.
     unity_line : :class:`bool`
         Add a line at y=1 for reference.
-
+    scatter_kw : :class:`dict`
+        Keyword parameters to be passed to the scatter plotting function.
+    line_kw : :class:`dict`
+        Keyword parameters to be passed to the line plotting function.
+    set_labels : :class:`bool`
+        Whether to set the x-axis ticklabels for the REE.
+    set_ticks : :class:`bool`
+        Whether to set the x-axis ticks according to the specified index.
     {otherparams}
 
     Returns
@@ -285,26 +346,33 @@ def REE_v_radii(
             mode=mode,
             unity_line=unity_line,
             indexes=indexes,
+            scatter_kw=scatter_kw,
+            line_kw=line_kw,
             **kwargs
         )
 
-    ax.set_xlabel(xtitle)
-    ax.set_xticks(xticks)
-    ax.set_xticklabels(xlabels, rotation=xlabelrotation)
-    if invertx:
-        xlim = xlim[::-1]
-    if xlim is not None:
-        ax.set_xlim(xlim)
-
     twinys = get_twins(ax, which="y")
     if len(twinys):
         _ax = twinys[0]
     else:
         _ax = ax.twiny()
-    _ax.set_xlabel(_xtitle)
-    _ax.set_xticks(_xticks)
-    _ax.set_xticklabels(_xlabels, rotation=_xlabelrotation)
-    _ax.set_xlim(ax.get_xlim())
+
+    if set_labels:
+        ax.set_xlabel(xtitle)
+        _ax.set_xlabel(_xtitle)
+
+    if set_ticks:
+        ax.set_xticks(xticks)
+        ax.set_xticklabels(xlabels, rotation=xlabelrotation)
+
+        if invertx:
+            xlim = xlim[::-1]
+        if xlim is not None:
+            ax.set_xlim(xlim)
+
+        _ax.set_xticks(_xticks)
+        _ax.set_xticklabels(_xlabels, rotation=_xlabelrotation)
+        _ax.set_xlim(ax.get_xlim())
     return ax
 
 
