@@ -3,10 +3,9 @@ import sympy
 import scipy
 from copy import copy
 from .meta import update_docstring_references
-import logging
+from .log import Handle
 
-logging.getLogger(__name__).addHandler(logging.NullHandler())
-logger = logging.getLogger(__name__)
+logger = Handle(__name__)
 
 
 def eigsorted(cov):
@@ -427,7 +426,6 @@ def signify_digit(n, unc=None, leeway=0, low_filter=True):
                 fmt = int
             else:
                 fmt = lambda x: x
-            print(n, round_to)
             sig_n = round(n, round_to)
             if low_filter and sig_n == 0.0:
                 return np.nan
