@@ -12,10 +12,9 @@ USE_PCOLOR : :class:`bool`
     of :func:`matplotlib.pyplot.pcolormesh`.
 """
 from sys import platform
-import logging
+from ..log import Handle
 
-logging.getLogger(__name__).addHandler(logging.NullHandler())
-logger = logging.getLogger(__name__)
+logger = Handle(__name__)
 
 if platform == "darwin":
     logger.debug('Using TkAgg renderer for Mac.')
