@@ -11,10 +11,9 @@ Todo
 import matplotlib.patches
 import matplotlib.lines
 from copy import copy
-import logging
+from ..log import Handle
 
-logging.getLogger(__name__).addHandler(logging.NullHandler())
-logger = logging.getLogger(__name__)
+logger = Handle(__name__)
 
 
 def proxy_rect(**kwargs):
