@@ -1,4 +1,3 @@
-import logging
 import numpy as np
 import pandas as pd
 from ...geochem import transform
@@ -6,9 +5,9 @@ from ...geochem import ind
 from ...geochem import parse
 from ...comp import codata
 from ..lambdas import orthogonal_polynomial_constants
+from ..log import Handle
 
-logging.getLogger(__name__).addHandler(logging.NullHandler())
-logger = logging.getLogger(__name__)
+logger = Handle(__name__)
 
 try:
     from sklearn.base import TransformerMixin, BaseEstimator
@@ -133,18 +132,23 @@ class LogTransform(BaseEstimator, TransformerMixin):
 
 
 class ALRTransform(BaseEstimator, TransformerMixin):
-    def __init__(self, **kwargs):
+    def __init__(self, label_mode="numeric", **kwargs):
         """Additive Log Ratio Transformer for scikit-learn like use."""
         self.kpairs = kwargs
+        self.label_mode = label_mode
         self.label = "ALR"
         self.forward = codata.ALR
         self.inverse = codata.inverse_ALR
 
     def transform(self, X, *args, **kwargs):
         if isinstance(X, pd.DataFrame):
-            out = X.pyrocomp.ALR(**kwargs)
+            out = X.pyrocomp.ALR(
+                label_mode=self.label_mode, **{**self.kpairs, **kwargs}
+            )
         elif isinstance(X, pd.Series):
-            out = X.to_frame().T.pyrocomp.ALR(**kwargs)
+            out = X.to_frame().T.pyrocomp.ALR(
+                label_mode=self.label_mode, **{**self.kpairs, **kwargs}
+            )
         else:
             out = self.forward(np.array(X), *args, **kwargs)
         return out
@@ -163,29 +167,34 @@ class ALRTransform(BaseEstimator, TransformerMixin):
 
 
 class CLRTransform(BaseEstimator, TransformerMixin):
-    def __init__(self, **kwargs):
+    def __init__(self, label_mode="numeric", **kwargs):
         """Centred Log Ratio Transformer for scikit-learn like use."""
         self.kpairs = kwargs
+        self.label_mode = label_mode
         self.label = "CLR"
         self.forward = codata.CLR
         self.inverse = codata.inverse_CLR
 
     def transform(self, X, *args, **kwargs):
         if isinstance(X, pd.DataFrame):
-            out = X.pyrocomp.CLR(**kwargs)
+            out = X.pyrocomp.CLR(
+                label_mode=self.label_mode, **{**self.kpairs, **kwargs}
+            )
         elif isinstance(X, pd.Series):
-            out = X.to_frame().T.pyrocomp.CLR(**kwargs)
+            out = X.to_frame().T.pyrocomp.CLR(
+                label_mode=self.label_mode, **{**self.kpairs, **kwargs}
+            )
         else:
-            out = self.forward(np.array(X), *args, **kwargs)
+            out = self.forward(np.array(X), *args, **{**self.kpairs, **kwargs})
         return out
 
     def inverse_transform(self, Y, *args, **kwargs):
         if isinstance(Y, pd.DataFrame):
-            out = Y.pyrocomp.inverse_CLR(**kwargs)
+            out = Y.pyrocomp.inverse_CLR(**{**self.kpairs, **kwargs})
         elif isinstance(Y, pd.Series):
-            out = Y.to_frame().T.pyrocomp.inverse_CLR(**kwargs)
+            out = Y.to_frame().T.pyrocomp.inverse_CLR(**{**self.kpairs, **kwargs})
         else:
-            out = self.inverse(np.array(Y), *args, **kwargs)
+            out = self.inverse(np.array(Y), *args, **{**self.kpairs, **kwargs})
         return out
 
     def fit(self, X, *args, **kwargs):
@@ -193,9 +202,10 @@ class CLRTransform(BaseEstimator, TransformerMixin):
 
 
 class ILRTransform(BaseEstimator, TransformerMixin):
-    def __init__(self, **kwargs):
+    def __init__(self, label_mode="numeric", **kwargs):
         """Isometric Log Ratio Transformer for scikit-learn like use."""
         self.kpairs = kwargs
+        self.label_mode = label_mode
         self.label = "ILR"
         self.forward = codata.ILR
         self.inverse = codata.inverse_ILR
@@ -204,9 +214,13 @@ class ILRTransform(BaseEstimator, TransformerMixin):
     def transform(self, X, *args, **kwargs):
         self.X = np.array(X)
         if isinstance(X, pd.DataFrame):
-            out = X.pyrocomp.ILR(**kwargs)
+            out = X.pyrocomp.ILR(
+                label_mode=self.label_mode, **{**self.kpairs, **kwargs}
+            )
         elif isinstance(X, pd.Series):
-            out = X.to_frame().T.pyrocomp.ILR(**kwargs)
+            out = X.to_frame().T.pyrocomp.ILR(
+                label_mode=self.label_mode, **{**self.kpairs, **kwargs}
+            )
         else:
             out = self.forward(np.array(X), *args, **kwargs)
         return out
