@@ -1,32 +1,56 @@
 """
 Baisc spatial utility functions.
 """
+
 import numpy as np
+import pandas as pd
+import functools
 import itertools
-import logging
+from psutil import virtual_memory  # memory check
+from .math import on_finite
+from .log import Handle
 
-logging.getLogger(__name__).addHandler(logging.NullHandler())
-logger = logging.getLogger(__name__)
+logger = Handle(__name__)
 
 
-def _spherical_law_cosinse_GC_distance(ps):
+def _get_sqare_grid_segment_indicies(size, segments):
+    """
+    Get the indexes for segment boundaries for iterating over a grid within an array.
+
+    Parameters
+    ----------
+    size : :class:`int`
+        Shape of the square array.
+    segments : :class:`int`
+        Number of segments for the grid.
+
+    Returns
+    --------
+    :class:`numpy.ndarray`
+    """
+    seg_size = size // segments
+    segx = [(seg_size * ix, seg_size * (ix + 1)) for ix in range(segments)]
+    segx[-1] = (seg_size * (segments - 1), size - 1)
+    return [[*a, *b] for a, b in itertools.product(segx, segx)]
+
+
+def _spherical_law_cosinse_GC_distance(φ1, φ2, λ1, λ2):
     """
     Spherical law of cosines calculation of distance between two points. Suffers from
     rounding errors for closer points.
 
     Parameters
     ----------
-    ps
+    φ1, φ2, λ1, λ2
         Numpy array wih latitudes and longitudes [x1, x2, y1, y2]
     """
-    φ1, φ2 = ps[2:]  # latitude
-    λ1, λ2 = ps[:2]  # longitude
+
     Δλ = np.abs(λ1 - λ2)
     # Δφ = np.abs(φ1 - φ2)
     return np.arccos(np.sin(φ1) * np.sin(φ2) + np.cos(φ1) * np.cos(φ2) * np.cos(Δλ))
 
 
-def _vicenty_GC_distance(ps):
+def _vicenty_GC_distance(φ1, φ2, λ1, λ2):
     """
     Vicenty formula for an ellipsoid with equal major and minor axes.
 
@@ -36,11 +60,11 @@ def _vicenty_GC_distance(ps):
 
     Parameters
     ----------
-    ps
-        Numpy array wih latitudes and longitudes [x1, x2, y1, y2]
+    φ1, φ2 : :class:`numpy.ndarray`
+        Numpy arrays wih latitudes.
+    λ1, λ2 : :class:`numpy.ndarray`
+        Numpy arrays wih longitude.
     """
-    φ1, φ2 = ps[2:]  # latitude
-    λ1, λ2 = ps[:2]  # longitude
     Δλ = np.abs(λ1 - λ2)
     # Δφ = np.abs(φ1 - φ2)
 
@@ -52,19 +76,19 @@ def _vicenty_GC_distance(ps):
     return np.abs(np.arctan2(_S, _C))
 
 
-def _haversine_GC_distance(ps):
+def _haversine_GC_distance(φ1, φ2, λ1, λ2):
     """
     Haversine formula for great circle distance. Suffers from rounding errors for
     antipodal points.
 
     Parameters
     ----------
-    ps : :class:`numpy.ndarray`
-        Numpy array wih latitudes and longitudes [x1, x2, y1, y2].
+    φ1, φ2 : :class:`numpy.ndarray`
+        Numpy arrays wih latitudes.
+    λ1, λ2 : :class:`numpy.ndarray`
+        Numpy arrays wih longitude.
 
     """
-    φ1, φ2 = ps[2:]  # latitude
-    λ1, λ2 = ps[:2]  # longitude
     Δλ = np.abs(λ1 - λ2)
     Δφ = np.abs(φ1 - φ2)
     return 2 * np.arcsin(
@@ -72,16 +96,40 @@ def _haversine_GC_distance(ps):
     )
 
 
+def _segmented_spatial_distance_matrix(
+    φ1, φ2, λ1, λ2, metric, dtype="float32", segs=10
+):
+    size = np.max([a.shape[0] for a in [φ1, φ2, λ1, λ2]])
+    angle = np.zeros((size, size), dtype=dtype)  # full matrix
+    for ix_s, ix_e, iy_s, iy_e in _get_sqare_grid_segment_indicies(size, segs):
+        angle[ix_s:ix_e, iy_s:iy_e] = metric(
+            φ1[ix_s:ix_e][:, np.newaxis],
+            φ2[iy_s:iy_e][np.newaxis, :],
+            λ1[ix_s:ix_e][:, np.newaxis],
+            λ2[iy_s:iy_e][np.newaxis, :],
+        )
+    return angle
+
+
 def great_circle_distance(
-    p1, p2, absolute=False, degrees=True, r=6371.0088, method=None
+    a,
+    b=None,
+    absolute=False,
+    degrees=True,
+    r=6371.0088,
+    method=None,
+    dtype="float32",
+    max_memory_fraction=0.25,
 ):
     """
     Calculate the great circle distance between two lat, long points.
 
     Parameters
     ----------
-    p1, p2 : :class:`float`
-        Lat-Long points to calculate distance between.
+    a, b : :class:`float` | :class:`numpy.ndarray`
+        Lat-Long points or arrays to calculate distance between. If only one array is
+        specified, a full distance matrix (i.e. calculate a point-to-point distance
+        for every combination of points) will be returned.
     absolute : :class:`bool`, :code:`False`
         Whether to return estimates of on-sphere distances [True], or simply return the
         central angle between the points.
@@ -92,14 +140,28 @@ def great_circle_distance(
     method : :class:`str`, :code:`{'vicenty', 'cosines', 'haversine'}`
         Which method to use for great circle distance calculation. Defaults to the
         Vicenty formula.
-
+    dtype : :class:`numpy.dtype`
+        Data type for distance arrays, to constrain memory management.
+    max_memory_fraction : :class:`float`
+        Constraint to switch to calculating mean distances where :code:`matrix=True`
+        and the distance matrix requires greater than a specified fraction of total
+        avaialbe physical memory.
     """
-    x1, y1 = p1
-    x2, y2 = p2
-    ps = np.array([x1, x2, y1, y2]).astype(np.float)
+    a = np.atleast_2d(np.array(a).astype(dtype))
+    matrix = False
+    if b is not None:
+        b = np.atleast_2d(np.array(b).astype(dtype))
+    else:
+        matrix = True
+        b = a.copy()
 
-    if degrees:
-        ps = np.deg2rad(ps)
+    # check the sizes of a and b - they should be the same
+
+    if degrees:  # convert from degrees if needed
+        a, b = np.deg2rad(a), np.deg2rad(b)
+
+    φ1, φ2 = a[:, 0], b[:, 0]  # latitudes
+    λ1, λ2 = a[:, 1], b[:, 1]  # longitudes
 
     if method is None:
         f = _vicenty_GC_distance
@@ -111,10 +173,52 @@ def great_circle_distance(
         else:  # Default to most precise
             f = _vicenty_GC_distance
 
-    angle = f(ps)
+    if matrix:
+        # if matrix mode we need to turn these 1d arrays into 2d
+        # but, with large arrays it'll spit out a memory error
+        # so instead we can try to build it numerically
+        size = np.max([a.shape[0] for a in [φ1, φ2, λ1, λ2]])
+        mem = virtual_memory().total  # total physical memory available
+        estimated_matrix_size = np.array([[1.0]], dtype=dtype).nbytes * size ** 2
+        logger.debug(
+            "Attempting to build {}x{} array of size {:.2f} Gb.".format(
+                size, size, estimated_matrix_size / 1024 ** 3
+            )
+        )
+        if estimated_matrix_size > (mem * max_memory_fraction):
+            logger.warn(
+                "Angle array for segmented distance matrix larger than maximum memory "
+                "fraction, computing mean global distances instead."
+            )
+            angle = np.zeros((size, 1))
+            # compute sum-distances for each lat-long pair
+            for ix, (_φ1, _λ1) in enumerate(np.vstack([φ1, λ1])):
+                angle[ix, 0] = f(_φ1, φ2, _λ1, λ2,)
+        else:
+            try:
+                angle = np.atleast_1d(
+                    f(
+                        φ1[:, np.newaxis],
+                        φ2[np.newaxis, :],
+                        λ1[:, np.newaxis],
+                        λ2[np.newaxis, :],
+                    )
+                )
+            except (MemoryError, ValueError):
+                logger.warn(
+                    "Cannot directly compute distance matrix, attempting segmented distance"
+                    " matrix instead."
+                )
+                # could set segs such that there is a maximum amount of memory per seg
+                angle = _segmented_spatial_distance_matrix(φ1, φ2, λ1, λ2, f)
+    else:
+        angle = np.atleast_1d(f(φ1, φ2, λ1, λ2))
 
-    if np.isnan(angle) and f != _vicenty_GC_distance:  # fallback for cos failure @ 0.
-        angle = _vicenty_GC_distance(ps)
+        if (
+            np.isnan(angle).any() and f != _vicenty_GC_distance
+        ):  # fallback for cos failure @ 0.
+            fltr = np.isnan(angle)
+            angle[fltr] = _vicenty_GC_distance(a[fltr, :], b[fltr, :])
 
     if absolute:
         return np.rad2deg(angle) * r
