@@ -3,13 +3,12 @@ import numpy as np
 from .meta import pyrolite_datafolder
 from .text import titlecase
 from collections import ChainMap, defaultdict
-import logging
+from .log import Handle
 
-logging.getLogger(__name__).addHandler(logging.NullHandler())
-logger = logging.getLogger(__name__)
+logger = Handle(__name__)
 
 
-__data__ = pyrolite_datafolder(subfolder="timescale") / "geotimescale_spans.csv"
+__data__ = pyrolite_datafolder(subfolder="timescale") / "geotimescale_202003.csv"
 __colors__ = pyrolite_datafolder(subfolder="timescale") / "timecolors.csv"
 
 
