@@ -1,9 +1,8 @@
 import numpy as np
 import pandas as pd
-import logging
+from .log import Handle
 
-logging.getLogger(__name__).addHandler(logging.NullHandler())
-logger = logging.getLogger(__name__)
+logger = Handle(__name__)
 
 
 __massunits__ = {
@@ -48,6 +47,6 @@ def scale(in_unit, target_unit="ppm"):
         scale = __UNITS__[in_unit] / __UNITS__[target_unit]
     else:
         unkn = [i for i in [in_unit, target_unit] if i not in __UNITS__]
-        logger.warn("Units not known: {}. Defaulting to unity.".format(unkn))
+        logger.warning("Units not known: {}. Defaulting to unity.".format(unkn))
         scale = 1.0
     return scale
